@@ -26,16 +26,42 @@ def get_opts_mapping_tag(parser, sub_program):
 sequence in R2 reads with all tag barcode sequence in barcode_fasta. 
 It will assign read to the tag with mismatch < len(tag barcode) / 10 + 1. 
 If no such tag exists, the read is classified as invalid.
+
+You can find the barcode fasta file under `celescope/data/Clindex`
+```
+>CLindex_TAG_1
+CGTGTTAGGGCCGAT
+>CLindex_TAG_2
+GAGTGGTTGCGCCAT
+>CLindex_TAG_3
+AAGTTGCCAAGGGCC
+>CLindex_TAG_4
+TAAGAGCCCGGCAAG
+>CLindex_TAG_5
+TGACCTGCTTCACGC
+>CLindex_TAG_6
+GAGACCCGTGGAATC
+>CLindex_TAG_7
+GTTATGCGACCGCGA
+>CLindex_TAG_8
+ATACGCAGGGTCCGA
+>CLindex_TAG_9
+AGCGGCATTTGGGAC
+>CLindex_TAG_10
+TCGCCAGCCAAGTCT
+>CLindex_TAG_11
+ACCAATGGCGCATGG
+>CLindex_TAG_12
+TCCTCCTAGCAACCC
+>CLindex_TAG_13
+GGCCGATACTTCAGC
+>CLindex_TAG_14
+CCGTTCGACTTGGTG
+>CLindex_TAG_15
+CGCAAGACACTCCAC
+>CLindex_TAG_16
+CTGCAACAAGGTCGC
 ```
->tag_0
-GGGCGTCTGTGACCGCGTGATACTGCATTGTAGACCGCCCAACTC
->tag_1
-TTCCTCCAGAGGAGACCGAGCCGGTCAATTCAGGAGAACGTCCGG
->tag_2
-AGGGCTAGGCGTGTCATTTGGCGAGGTCCTGAGGTCATGGAGCCA
->tag_3
-CACTGGTCATCGACACTGGGAACCTGAGGTGAGTTCGCGCGCAAG
-```  
 """,
         required=True,
     )
