@@ -1,9 +1,8 @@
 
 import os
 import re
-import subprocess
 
-from celescope.rna.mkref import parse_genomeDir_rna
+from celescope.rna.mkref import Mkref_rna
 from celescope.tools.step import Step, s_common
 import celescope.tools.utils as utils
 
@@ -11,31 +10,26 @@ import celescope.tools.utils as utils
 class FeatureCounts(Step):
     """
     Features
-
     - Assigning uniquely mapped reads to genomic features with FeatureCounts.
-
     Output
     - `{sample}` Numbers of reads assigned to features (or meta-features).
-
     - `{sample}_summary` Stat info for the overall summrization results, including number of 
     successfully assigned reads and number of reads that failed to be assigned due to 
     various reasons (these reasons are included in the stat info).
-
     - `{sample}_Aligned.sortedByCoord.out.bam.featureCounts.bam` featureCounts output BAM, 
     sorted by coordinates；BAM file contains tags as following(Software Version>=1.1.8):
         - CB cell barcode
         - UB UMI
         - GN gene name
         - GX gene id
-
     - `{sample}_name_sorted.bam` featureCounts output BAM, sorted by read name.
     """
 
-    def __init__(self, args, step_name):
-        Step.__init__(self, args, step_name)
+    def __init__(self, args, display_title=None):
+        Step.__init__(self, args, display_title=display_title)
 
         # set
-        self.gtf = parse_genomeDir_rna(self.args.genomeDir)['gtf']
+        self.gtf = Mkref_rna.parse_genomeDir(self.args.genomeDir)['gtf']
         self.featureCounts_param = args.featureCounts_param
 
         # out files
@@ -45,36 +39,49 @@ class FeatureCounts(Step):
         self.featureCount_log_file = f'{self.out_prefix}.summary'
 
     def format_stat(self):
-        tmp_arr = []
-        fh = open(self.featureCount_log_file, 'r')
-        with open(self.stat_file, 'w') as stat_fh:
-            p1 = re.compile(r'Assigned.*?(\d+)', flags=re.S)
-            p2 = re.compile(r'Unassigned_NoFeatures.*?(\d+)', flags=re.S)
-            p3 = re.compile(r'Unassigned_Ambiguity.*?(\d+)', flags=re.S)
+        metrics_strs = ['Assigned', 'Unassigned_NoFeatures', 'Unassigned_Ambiguity']
+        metrics_numbers = {}
+        metrics_compiled = {}
+
+        for metrics_str in metrics_strs:
+            raw_str = re.escape(metrics_str) + r'.*?(\d+)'
+            compiled = re.compile(raw_str, flags=re.S)
+            metrics_compiled[metrics_str] = compiled
+
+        with open(self.featureCount_log_file, 'r') as fh:
+
             for line in fh:
-                if line.strip() == '':
+                line = line.strip()
+                if not line:
                     continue
 
-                m1 = p1.search(line.strip())
-                if m1:
-                    tmp_arr.append(int(m1.group(1)))
+                for metrics_str in metrics_compiled:
+                    compiled = metrics_compiled[metrics_str]
+                    match = compiled.search(line)
+                    if match:
+                        metrics_numbers[metrics_str] = int(match.group(1))
+                        break
 
-                m2 = p2.search(line)
-                if m2:
-                    tmp_arr.append(int(m2.group(1)))
+            total = sum(metrics_numbers.values())
 
-                m3 = p3.search(line)
-                if m3:
-                    tmp_arr.append(int(m3.group(1)))
-
-            total = sum(tmp_arr)
-            tmp_arr = [
-                '%s(%.2f%%)' %
-                (utils.format_number(n), (n + 0.0) / total * 100) for n in tmp_arr]
-            for t, s in zip(['Assigned', 'Unassigned_NoFeatures',
-                            'Unassigned_Ambiguity'], tmp_arr):
-                stat_fh.write('%s: %s\n' % (t, s))
-        fh.close()
+            self.add_metric(
+                name='Assigned',
+                value=metrics_numbers['Assigned'],
+                total=total,
+                help_info='reads that can be successfully assigned without ambiguity'
+            )
+            self.add_metric(
+                name='Unassigned_NoFeatures',
+                value=metrics_numbers['Unassigned_NoFeatures'],
+                total=total,
+                help_info='alignments that do not overlap any feature'
+            )
+            self.add_metric(
+                name='Unassigned_Ambiguity',
+                value=metrics_numbers['Unassigned_Ambiguity'],
+                total=total,
+                help_info='alignments that overlap two or more features'
+            )
 
     @utils.add_log
     def run_featureCounts(self):
@@ -90,28 +97,31 @@ class FeatureCounts(Step):
         )
         if self.featureCounts_param:
             cmd += (" " + self.featureCounts_param)
-        FeatureCounts.run_featureCounts.logger.info(cmd)
-        subprocess.check_call(cmd, shell=True)
-
+        self.debug_subprocess_call(cmd)
 
     def run(self):
+
         self.run_featureCounts()
         samtools_runner = utils.Samtools(
             in_bam=self.featureCounts_bam,
             out_bam=self.featureCounts_bam,
             threads=self.thread,
-            )
+            debug=self.debug
+        )
         samtools_runner.add_tag(self.gtf)
-        samtools_runner.temp_sam2bam(by='name')
+        samtools_runner.temp_sam2bam(by='coord')
+        samtools_runner.samtools_sort(
+            in_file=self.featureCounts_bam,
+            out_file=self.name_sorted_bam,
+            by='name',
+        )
         self.format_stat()
-        self.clean_up()
 
 
 @utils.add_log
 def featureCounts(args):
-    step_name = "featureCounts"
-    featureCounts_obj = FeatureCounts(args, step_name)
-    featureCounts_obj.run()
+    with FeatureCounts(args) as runner:
+        runner.run()
 
 
 def get_opts_featureCounts(parser, sub_program):
